if [ -z ${CONDA_BUILD+x} ]; then
    source /opt/concourse/worker/volumes/live/4fc06327-a644-4904-77c6-8e7adb103dc2/volume/pymongo_1614007729463/work/build_env_setup.sh
fi
python setup.py install --single-version-externally-managed --record=record.txt